(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'react-touch-position', './EnlargedImage'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('react-touch-position'), require('./EnlargedImage'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.reactTouchPosition, global.EnlargedImage);
        global.ReactImageMagnifyTouch = mod.exports;
    }
})(this, function (exports, _react, _reactTouchPosition, _EnlargedImage) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });
    exports.ImageShape = undefined;

    var _react2 = _interopRequireDefault(_react);

    var _reactTouchPosition2 = _interopRequireDefault(_reactTouchPosition);

    var _EnlargedImage2 = _interopRequireDefault(_EnlargedImage);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var ReactImageMagnifyTouch = function ReactImageMagnifyTouch(_ref) {
        var className = _ref.className;
        var enlargedImageContainerClassName = _ref.enlargedImageContainerClassName;
        var enlargedImageContainerStyle = _ref.enlargedImageContainerStyle;
        var enlargedImageClassName = _ref.enlargedImageClassName;
        var enlargedImageStyle = _ref.enlargedImageStyle;
        var fadeDurationInMs = _ref.fadeDurationInMs;
        var isActivatedOnTouch = _ref.isActivatedOnTouch;
        var imageClassName = _ref.imageClassName;
        var imageStyle = _ref.imageStyle;
        var largeImage = _ref.largeImage;
        var pressDuration = _ref.pressDuration;
        var pressMoveThreshold = _ref.pressMoveThreshold;
        var smallImage = _ref.smallImage;
        var style = _ref.style;
        var enlargedImagePosition = _ref.enlargedImagePosition;


        var cursorOffset = {
            x: Math.round(smallImage.width / largeImage.width * smallImage.width / 2),
            y: Math.round(smallImage.height / largeImage.height * smallImage.height / 2)
        };

        return _react2.default.createElement(
            _reactTouchPosition2.default,
            {
                className: className,
                isActivatedOnTouch: isActivatedOnTouch,
                mapPropNames: function mapPropNames(_ref2) {
                    var isActive = _ref2.isActive;
                    var isTouchOutside = _ref2.isTouchOutside;
                    var touchPosition = _ref2.touchPosition;
                    return {
                        isHovering: isActive,
                        isTouchOutside: isTouchOutside,
                        cursorPosition: touchPosition
                    };
                },
                pressDuration: pressDuration,
                pressMoveThreshold: pressMoveThreshold,
                style: Object.assign({
                    width: smallImage.width + 'px',
                    height: smallImage.height + 'px',
                    position: 'relative'
                }, style)
            },
            _react2.default.createElement('img', {
                src: smallImage.src,
                alt: smallImage.alt,
                className: imageClassName,
                style: Object.assign({
                    width: smallImage.width + 'px',
                    height: smallImage.height + 'px',
                    pointerEvents: 'none'
                }, imageStyle)
            }),
            _react2.default.createElement(_EnlargedImage2.default, {
                containerClassName: enlargedImageContainerClassName,
                containerStyle: enlargedImageContainerStyle,
                cursorOffset: cursorOffset,
                fadeDurationInMs: fadeDurationInMs,
                imageClassName: enlargedImageClassName,
                imageStyle: Object.assign({}, enlargedImageStyle, { pointerEvents: 'none' }),
                isRenderOnDemand: false,
                largeImage: largeImage,
                smallImage: smallImage,
                imagePosition: enlargedImagePosition
            })
        );
    };

    var ImageShape = exports.ImageShape = _react.PropTypes.shape({
        alt: _react.PropTypes.string,
        src: _react.PropTypes.string.isRequired,
        srcSet: _react.PropTypes.string,
        width: _react.PropTypes.number.isRequired,
        height: _react.PropTypes.number.isRequired
    });

    ReactImageMagnifyTouch.propTypes = {
        className: _react.PropTypes.string,
        enlargedImageContainerClassName: _react.PropTypes.string,
        enlargedImageContainerStyle: _react.PropTypes.object,
        enlargedImageClassName: _react.PropTypes.string,
        enlargedImageStyle: _react.PropTypes.object,
        fadeDurationInMs: _react.PropTypes.number,
        isActivatedOnTouch: _react.PropTypes.bool,
        imageClassName: _react.PropTypes.string,
        imageStyle: _react.PropTypes.object,
        largeImage: ImageShape,
        pressDuration: _react.PropTypes.number,
        pressMoveThreshold: _react.PropTypes.number,
        smallImage: ImageShape,
        style: _react.PropTypes.object,
        enlargedImagePosition: _react.PropTypes.oneOf(['beside', 'over'])
    };

    ReactImageMagnifyTouch.defaultProps = {
        fadeDurationInMs: 500,
        enlargedImagePosition: 'over'
    };

    exports.default = ReactImageMagnifyTouch;
});